@@ -7,21 +7,27 @@ from . import (
     processing,
     filter_month,
     time_series,
+    filtering,
+    transform,
     # submodules
     tracmass,
     origin,
 )
+from .version import pkg_version as __version__
 from .tracmass import seeding
 from .origin import pca
 
 __all__ = [
     "version",
+    "__version__",
     # modules
     "constants",
     "processing",
     "filter_month",
     "spgsi",
     "time_series",
+    "filtering",
+    "transform",
     # submodule
     "tracmass",
     "seeding",
